@@ -28,7 +28,7 @@ import './editor.less'
 import getCodeMirrorDefaultOptions from './get-cm-options'
 import safeAssign from '@common/util/safe-assign'
 import countWords from '@common/util/count-words'
-import md2html from '@common/util/md-to-html'
+import { getConverter } from '@common/util/md-to-html'
 import generateKeymap from './generate-keymap'
 import generateTableOfContents from './util/generate-toc'
 
@@ -67,10 +67,8 @@ import noteTooltipsHook from './hooks/note-preview'
 
 import displayContextMenu from './display-context-menu'
 
-import { IpcRenderer } from 'electron'
-
-const ipcRenderer: IpcRenderer = (window as any).ipc
-const clipboard = (window as any).clipboard
+const ipcRenderer = window.ipc
+const clipboard = window.clipboard
 
 export default class MarkdownEditor extends EventEmitter {
   private readonly _instance: CodeMirror.Editor
@@ -79,6 +77,7 @@ export default class MarkdownEditor extends EventEmitter {
   private _currentDocumentMode: string
   private _cmOptions: any
   private _countChars: boolean
+  private readonly _md2html: ReturnType<typeof getConverter>
 
   /**
    * Creates a new MarkdownEditor instance attached to the anchorElement
@@ -94,6 +93,8 @@ export default class MarkdownEditor extends EventEmitter {
     this._cmOptions = getCodeMirrorDefaultOptions(this)
     this._countChars = false
 
+    this._md2html = getConverter(window.getCitation)
+
     // Parse the anchorElement until we get something useful
     if (typeof anchorElement === 'string' && document.getElementById(anchorElement) !== null) {
       const anchor = document.getElementById(anchorElement)
@@ -199,6 +200,14 @@ export default class MarkdownEditor extends EventEmitter {
         event.preventDefault()
         ;(event as any).codemirrorIgnore = true
         this.emit('zettelkasten-tag', tokenInfo.string)
+      } else if (event.target !== null) {
+        // It could be that it's a frontmatter tag. In that case, we shouldn't
+        // check the tokenType, but rather class names
+        if ((event.target as HTMLElement).classList.contains('zkn-tag')) {
+          event.preventDefault()
+          ;(event as any).codemirrorIgnore = true
+          this.emit('zettelkasten-tag', `#${(event.target as HTMLElement).textContent as string}`)
+        }
       }
     })
 
@@ -312,7 +321,7 @@ export default class MarkdownEditor extends EventEmitter {
   copyAsHTML (): void {
     if (!this._instance.somethingSelected()) return
     let md = this._instance.getSelections().join(' ')
-    let html = md2html(md)
+    let html = this._md2html(md)
     // Write both the HTML and the Markdown
     // (as fallback plain text) to the clipboard
     clipboard.write({ 'text': md, 'html': html })
